# coding: utf-8

"""
    CardPay REST API

    Welcome to the CardPay REST API. The CardPay API uses HTTP verbs and a [REST](https://en.wikipedia.org/wiki/Representational_state_transfer) resources endpoint structure (see more info about REST). Request and response payloads are formatted as JSON. Merchant uses API to create payments, refunds, payouts or recurrings, check or update transaction status and get information about created transactions. In API authentication process based on [OAuth 2.0](https://oauth.net/2/) standard. For recent changes see changelog section.  # noqa: E501

    OpenAPI spec version: 3.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six

from cardpay.model.payment_request_customer import PaymentRequestCustomer  # noqa: F401,E501
from cardpay.model.payment_response_card_account import PaymentResponseCardAccount  # noqa: F401,E501
from cardpay.model.payment_response_cryptocurrency_account import PaymentResponseCryptocurrencyAccount  # noqa: F401,E501
from cardpay.model.payment_response_payment_data import PaymentResponsePaymentData  # noqa: F401,E501
from cardpay.model.transaction_response_e_wallet_account import TransactionResponseEWalletAccount  # noqa: F401,E501
from cardpay.model.transaction_response_merchant_order import TransactionResponseMerchantOrder  # noqa: F401,E501


class PaymentResponse(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'customer': 'PaymentRequestCustomer',
        'payment_method': 'str',
        'merchant_order': 'TransactionResponseMerchantOrder',
        'payment_data': 'PaymentResponsePaymentData',
        'card_account': 'PaymentResponseCardAccount',
        'cryptocurrency_account': 'PaymentResponseCryptocurrencyAccount',
        'ewallet_account': 'TransactionResponseEWalletAccount'
    }

    attribute_map = {
        'customer': 'customer',
        'payment_method': 'payment_method',
        'merchant_order': 'merchant_order',
        'payment_data': 'payment_data',
        'card_account': 'card_account',
        'cryptocurrency_account': 'cryptocurrency_account',
        'ewallet_account': 'ewallet_account'
    }

    def __init__(self, customer=None, payment_method=None, merchant_order=None, payment_data=None, card_account=None, cryptocurrency_account=None, ewallet_account=None):  # noqa: E501
        """PaymentResponse - a model defined in Swagger"""  # noqa: E501

        self._customer = None
        self._payment_method = None
        self._merchant_order = None
        self._payment_data = None
        self._card_account = None
        self._cryptocurrency_account = None
        self._ewallet_account = None
        self.discriminator = None

        if customer is not None:
            self.customer = customer
        if payment_method is not None:
            self.payment_method = payment_method
        if merchant_order is not None:
            self.merchant_order = merchant_order
        if payment_data is not None:
            self.payment_data = payment_data
        if card_account is not None:
            self.card_account = card_account
        if cryptocurrency_account is not None:
            self.cryptocurrency_account = cryptocurrency_account
        if ewallet_account is not None:
            self.ewallet_account = ewallet_account

    @property
    def customer(self):
        """Gets the customer of this PaymentResponse.  # noqa: E501

        Customer data  # noqa: E501

        :return: The customer of this PaymentResponse.  # noqa: E501
        :rtype: PaymentRequestCustomer
        """
        return self._customer

    @customer.setter
    def customer(self, customer):
        """Sets the customer of this PaymentResponse.

        Customer data  # noqa: E501

        :param customer: The customer of this PaymentResponse.  # noqa: E501
        :type: PaymentRequestCustomer
        """

        self._customer = customer

    @property
    def payment_method(self):
        """Gets the payment_method of this PaymentResponse.  # noqa: E501

        Payment method  # noqa: E501

        :return: The payment_method of this PaymentResponse.  # noqa: E501
        :rtype: str
        """
        return self._payment_method

    @payment_method.setter
    def payment_method(self, payment_method):
        """Sets the payment_method of this PaymentResponse.

        Payment method  # noqa: E501

        :param payment_method: The payment_method of this PaymentResponse.  # noqa: E501
        :type: str
        """

        self._payment_method = payment_method

    @property
    def merchant_order(self):
        """Gets the merchant_order of this PaymentResponse.  # noqa: E501

        Merchant order data  # noqa: E501

        :return: The merchant_order of this PaymentResponse.  # noqa: E501
        :rtype: TransactionResponseMerchantOrder
        """
        return self._merchant_order

    @merchant_order.setter
    def merchant_order(self, merchant_order):
        """Sets the merchant_order of this PaymentResponse.

        Merchant order data  # noqa: E501

        :param merchant_order: The merchant_order of this PaymentResponse.  # noqa: E501
        :type: TransactionResponseMerchantOrder
        """

        self._merchant_order = merchant_order

    @property
    def payment_data(self):
        """Gets the payment_data of this PaymentResponse.  # noqa: E501

        Payment data  # noqa: E501

        :return: The payment_data of this PaymentResponse.  # noqa: E501
        :rtype: PaymentResponsePaymentData
        """
        return self._payment_data

    @payment_data.setter
    def payment_data(self, payment_data):
        """Sets the payment_data of this PaymentResponse.

        Payment data  # noqa: E501

        :param payment_data: The payment_data of this PaymentResponse.  # noqa: E501
        :type: PaymentResponsePaymentData
        """

        self._payment_data = payment_data

    @property
    def card_account(self):
        """Gets the card_account of this PaymentResponse.  # noqa: E501

        Card account data *(for BANKCARD payment method only)*  # noqa: E501

        :return: The card_account of this PaymentResponse.  # noqa: E501
        :rtype: PaymentResponseCardAccount
        """
        return self._card_account

    @card_account.setter
    def card_account(self, card_account):
        """Sets the card_account of this PaymentResponse.

        Card account data *(for BANKCARD payment method only)*  # noqa: E501

        :param card_account: The card_account of this PaymentResponse.  # noqa: E501
        :type: PaymentResponseCardAccount
        """

        self._card_account = card_account

    @property
    def cryptocurrency_account(self):
        """Gets the cryptocurrency_account of this PaymentResponse.  # noqa: E501

        Cryptocurrency account data *(for BITCOIN payment method only)*  # noqa: E501

        :return: The cryptocurrency_account of this PaymentResponse.  # noqa: E501
        :rtype: PaymentResponseCryptocurrencyAccount
        """
        return self._cryptocurrency_account

    @cryptocurrency_account.setter
    def cryptocurrency_account(self, cryptocurrency_account):
        """Sets the cryptocurrency_account of this PaymentResponse.

        Cryptocurrency account data *(for BITCOIN payment method only)*  # noqa: E501

        :param cryptocurrency_account: The cryptocurrency_account of this PaymentResponse.  # noqa: E501
        :type: PaymentResponseCryptocurrencyAccount
        """

        self._cryptocurrency_account = cryptocurrency_account

    @property
    def ewallet_account(self):
        """Gets the ewallet_account of this PaymentResponse.  # noqa: E501

        eWallet account data *(for ALIPAY, QIWI, WEBMONEY, NETELLER, YANDEXMONEY, DIRECTBANKINGNGA, AQRCODE, AIRTEL, MPESA, MTN, UGANDAMOBILE, VODAFONE, TIGO and 'Latin America' payment methods only)*  # noqa: E501

        :return: The ewallet_account of this PaymentResponse.  # noqa: E501
        :rtype: TransactionResponseEWalletAccount
        """
        return self._ewallet_account

    @ewallet_account.setter
    def ewallet_account(self, ewallet_account):
        """Sets the ewallet_account of this PaymentResponse.

        eWallet account data *(for ALIPAY, QIWI, WEBMONEY, NETELLER, YANDEXMONEY, DIRECTBANKINGNGA, AQRCODE, AIRTEL, MPESA, MTN, UGANDAMOBILE, VODAFONE, TIGO and 'Latin America' payment methods only)*  # noqa: E501

        :param ewallet_account: The ewallet_account of this PaymentResponse.  # noqa: E501
        :type: TransactionResponseEWalletAccount
        """

        self._ewallet_account = ewallet_account

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                if value is not None:
                    result[attr] = value
        if issubclass(PaymentResponse, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, PaymentResponse):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    CardPay REST API

    Welcome to the CardPay REST API. The CardPay API uses HTTP verbs and a [REST](https://en.wikipedia.org/wiki/Representational_state_transfer) resources endpoint structure (see more info about REST). Request and response payloads are formatted as JSON. Merchant uses API to create payments, refunds, payouts or recurrings, check or update transaction status and get information about created transactions. In API authentication process based on [OAuth 2.0](https://oauth.net/2/) standard. For recent changes see changelog section.  # noqa: E501

    OpenAPI spec version: 3.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six


class RefundRequestRefundData(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'amount': 'float',
        'currency': 'str'
    }

    attribute_map = {
        'amount': 'amount',
        'currency': 'currency'
    }

    def __init__(self, amount=None, currency=None):  # noqa: E501
        """RefundRequestRefundData - a model defined in Swagger"""  # noqa: E501

        self._amount = None
        self._currency = None
        self.discriminator = None

        if amount is not None:
            self.amount = amount
        if currency is not None:
            self.currency = currency

    @property
    def amount(self):
        """Gets the amount of this RefundRequestRefundData.  # noqa: E501

        Amount to be refunded. If 'amount' field is omitted then all remaining amount will be refunded  # noqa: E501

        :return: The amount of this RefundRequestRefundData.  # noqa: E501
        :rtype: float
        """
        return self._amount

    @amount.setter
    def amount(self, amount):
        """Sets the amount of this RefundRequestRefundData.

        Amount to be refunded. If 'amount' field is omitted then all remaining amount will be refunded  # noqa: E501

        :param amount: The amount of this RefundRequestRefundData.  # noqa: E501
        :type: float
        """
        if amount is not None and amount <= 0:  # noqa: E501
            raise ValueError("Invalid value for `amount`, must be a value greater than `0`")  # noqa: E501

        self._amount = amount

    @property
    def currency(self):
        """Gets the currency of this RefundRequestRefundData.  # noqa: E501

        [ISO 4217](https://en.wikipedia.org/wiki/ISO_4217) currency code. Not valid without 'amount' field. Must be equal to initial payment currency  # noqa: E501

        :return: The currency of this RefundRequestRefundData.  # noqa: E501
        :rtype: str
        """
        return self._currency

    @currency.setter
    def currency(self, currency):
        """Sets the currency of this RefundRequestRefundData.

        [ISO 4217](https://en.wikipedia.org/wiki/ISO_4217) currency code. Not valid without 'amount' field. Must be equal to initial payment currency  # noqa: E501

        :param currency: The currency of this RefundRequestRefundData.  # noqa: E501
        :type: str
        """

        self._currency = currency

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                if value is not None:
                    result[attr] = value
        if issubclass(RefundRequestRefundData, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, RefundRequestRefundData):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    CardPay REST API

    Welcome to the CardPay REST API. The CardPay API uses HTTP verbs and a [REST](https://en.wikipedia.org/wiki/Representational_state_transfer) resources endpoint structure (see more info about REST). Request and response payloads are formatted as JSON. Merchant uses API to create payments, refunds, payouts or recurrings, check or update transaction status and get information about created transactions. In API authentication process based on [OAuth 2.0](https://oauth.net/2/) standard. For recent changes see changelog section.  # noqa: E501

    OpenAPI spec version: 3.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six


class BillingAddress(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'city': 'str',
        'country': 'str',
        'phone': 'str',
        'state': 'str',
        'street': 'str',
        'zip': 'str'
    }

    attribute_map = {
        'city': 'city',
        'country': 'country',
        'phone': 'phone',
        'state': 'state',
        'street': 'street',
        'zip': 'zip'
    }

    def __init__(self, city=None, country=None, phone=None, state=None, street=None, zip=None):  # noqa: E501
        """BillingAddress - a model defined in Swagger"""  # noqa: E501

        self._city = None
        self._country = None
        self._phone = None
        self._state = None
        self._street = None
        self._zip = None
        self.discriminator = None

        self.city = city
        self.country = country
        self.phone = phone
        if state is not None:
            self.state = state
        self.street = street
        self.zip = zip

    @property
    def city(self):
        """Gets the city of this BillingAddress.  # noqa: E501

        Billing city. May include whitespaces, hyphens, apostrophes, commas and dots  # noqa: E501

        :return: The city of this BillingAddress.  # noqa: E501
        :rtype: str
        """
        return self._city

    @city.setter
    def city(self, city):
        """Sets the city of this BillingAddress.

        Billing city. May include whitespaces, hyphens, apostrophes, commas and dots  # noqa: E501

        :param city: The city of this BillingAddress.  # noqa: E501
        :type: str
        """
        if city is None:
            raise ValueError("Invalid value for `city`, must not be `None`")  # noqa: E501
        if city is not None and len(city) > 20:
            raise ValueError("Invalid value for `city`, length must be less than or equal to `20`")  # noqa: E501
        if city is not None and len(city) < 0:
            raise ValueError("Invalid value for `city`, length must be greater than or equal to `0`")  # noqa: E501

        self._city = city

    @property
    def country(self):
        """Gets the country of this BillingAddress.  # noqa: E501

        [ISO 3166-1](https://en.wikipedia.org/wiki/ISO_3166-1) code of billing country: 2 or 3 latin letters or numeric code   # noqa: E501

        :return: The country of this BillingAddress.  # noqa: E501
        :rtype: str
        """
        return self._country

    @country.setter
    def country(self, country):
        """Sets the country of this BillingAddress.

        [ISO 3166-1](https://en.wikipedia.org/wiki/ISO_3166-1) code of billing country: 2 or 3 latin letters or numeric code   # noqa: E501

        :param country: The country of this BillingAddress.  # noqa: E501
        :type: str
        """
        if country is None:
            raise ValueError("Invalid value for `country`, must not be `None`")  # noqa: E501

        self._country = country

    @property
    def phone(self):
        """Gets the phone of this BillingAddress.  # noqa: E501

        Valid Customer phone number  # noqa: E501

        :return: The phone of this BillingAddress.  # noqa: E501
        :rtype: str
        """
        return self._phone

    @phone.setter
    def phone(self, phone):
        """Sets the phone of this BillingAddress.

        Valid Customer phone number  # noqa: E501

        :param phone: The phone of this BillingAddress.  # noqa: E501
        :type: str
        """
        if phone is None:
            raise ValueError("Invalid value for `phone`, must not be `None`")  # noqa: E501
        if phone is not None and len(phone) > 20:
            raise ValueError("Invalid value for `phone`, length must be less than or equal to `20`")  # noqa: E501
        if phone is not None and len(phone) < 5:
            raise ValueError("Invalid value for `phone`, length must be greater than or equal to `5`")  # noqa: E501
        if phone is not None and not re.search(r'[0-9|+|\\-|w|p|(|)|\\s]+', phone):  # noqa: E501
            raise ValueError(r"Invalid value for `phone`, must be a follow pattern or equal to `/[0-9|+|\\-|w|p|(|)|\\s]+/`")  # noqa: E501

        self._phone = phone

    @property
    def state(self):
        """Gets the state of this BillingAddress.  # noqa: E501

        Billing state or province. May include whitespaces, hyphens, apostrophes, commas and dots  # noqa: E501

        :return: The state of this BillingAddress.  # noqa: E501
        :rtype: str
        """
        return self._state

    @state.setter
    def state(self, state):
        """Sets the state of this BillingAddress.

        Billing state or province. May include whitespaces, hyphens, apostrophes, commas and dots  # noqa: E501

        :param state: The state of this BillingAddress.  # noqa: E501
        :type: str
        """
        if state is not None and len(state) > 20:
            raise ValueError("Invalid value for `state`, length must be less than or equal to `20`")  # noqa: E501
        if state is not None and len(state) < 0:
            raise ValueError("Invalid value for `state`, length must be greater than or equal to `0`")  # noqa: E501

        self._state = state

    @property
    def street(self):
        """Gets the street of this BillingAddress.  # noqa: E501

        Billing street address. May include whitespaces, hyphens, apostrophes, commas, quotes, dots, slashes and semicolons  # noqa: E501

        :return: The street of this BillingAddress.  # noqa: E501
        :rtype: str
        """
        return self._street

    @street.setter
    def street(self, street):
        """Sets the street of this BillingAddress.

        Billing street address. May include whitespaces, hyphens, apostrophes, commas, quotes, dots, slashes and semicolons  # noqa: E501

        :param street: The street of this BillingAddress.  # noqa: E501
        :type: str
        """
        if street is None:
            raise ValueError("Invalid value for `street`, must not be `None`")  # noqa: E501
        if street is not None and len(street) > 100:
            raise ValueError("Invalid value for `street`, length must be less than or equal to `100`")  # noqa: E501
        if street is not None and len(street) < 2:
            raise ValueError("Invalid value for `street`, length must be greater than or equal to `2`")  # noqa: E501

        self._street = street

    @property
    def zip(self):
        """Gets the zip of this BillingAddress.  # noqa: E501

        Billing postal code  # noqa: E501

        :return: The zip of this BillingAddress.  # noqa: E501
        :rtype: str
        """
        return self._zip

    @zip.setter
    def zip(self, zip):
        """Sets the zip of this BillingAddress.

        Billing postal code  # noqa: E501

        :param zip: The zip of this BillingAddress.  # noqa: E501
        :type: str
        """
        if zip is None:
            raise ValueError("Invalid value for `zip`, must not be `None`")  # noqa: E501
        if zip is not None and len(zip) > 12:
            raise ValueError("Invalid value for `zip`, length must be less than or equal to `12`")  # noqa: E501
        if zip is not None and len(zip) < 0:
            raise ValueError("Invalid value for `zip`, length must be greater than or equal to `0`")  # noqa: E501

        self._zip = zip

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                if value is not None:
                    result[attr] = value
        if issubclass(BillingAddress, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, BillingAddress):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
